@@ -149,11 +149,12 @@ class ComplexArguments:
         argument: Arguments = self._arg_objs[sub]
         for k, _ in args.__dict__.items():
             Inspector.set_attr_from(args, argument.destObj, k, False, True)
+        # print("Argument Obj: {}".format(str(argument.destObj)))
         return argument.destObj
 
     def parse(self, args=None):
         args, _ = self._parser.parse_known_args(args)
-        print("parsed args:{}".format(str(args)))
+        # print("parsed input args:{}".format(str(args)))
         if not self._arg_objs:
             return None, None
         return args.cmd, self._get_arg_obj(args.cmd, args)
